Distributed file system based on <https://github.com/bmuller/kademlia>


## Basic Usage

- Clone the repo and run poetry install
- Run server.py in one pc or several pc in a local network
- Run cli.py in any pc of the network and start playing with the system

## Installation

- pip install kade-drive
  
### Tests

To run tests make shure that there is at least one server in the network.
